@@ -94,16 +94,15 @@ qmidictlMainForm::qmidictlMainForm ( QWidget *pParent )
 	m_iMidiInLed  = 0;
 	m_iMidiOutLed = 0;
 
-	// Kind of soft-mutex.
-	m_iBusy = 0;
-
 	// Hack the jog-wheel dial style and palette...
 	m_pDialStyle = new qmidictlDialStyle();
 	m_ui.jogWheelDial->setStyle(m_pDialStyle);
 
 	// Enable multi-gestures...
+#ifdef CONFIG_MULTI_TOUCH
 	m_ui.MainCentralWidget->setAttribute(Qt::WA_AcceptTouchEvents);
 	m_ui.MainCentralWidget->installEventFilter(this);
+#endif
 
 #if defined(Q_OS_ANDROID)
 
@@ -307,7 +306,7 @@ void qmidictlMainForm::initMixerStrip ( qmidictlMixerStrip *pStrip )
 // Strip states methods.
 void qmidictlMainForm::initStripStates (void)
 {
-	int iStrips = 4 * m_iStripPages;
+	const int iStrips = 4 * m_iStripPages;
 
 	m_pStripStates = new StripState [iStrips];
 
@@ -348,7 +347,7 @@ void qmidictlMainForm::loadStripState ( qmidictlMixerStrip *pStrip, int iStrip )
 
 void qmidictlMainForm::saveStripPage ( int iStripPage )
 {
-	int iStrip = (iStripPage * 4);
+	const int iStrip = (iStripPage * 4);
 
 	saveStripState(m_ui.strip1, iStrip + 0);
 	saveStripState(m_ui.strip2, iStrip + 1);
@@ -359,7 +358,7 @@ void qmidictlMainForm::saveStripPage ( int iStripPage )
 
 void qmidictlMainForm::loadStripPage ( int iStripPage )
 {
-	int iStrip = (iStripPage * 4);
+	const int iStrip = (iStripPage * 4);
 
 	loadStripState(m_ui.strip1, iStrip + 0);
 	loadStripState(m_ui.strip2, iStrip + 1);
@@ -427,7 +426,7 @@ void qmidictlMainForm::sendMmcMaskedWrite (
 	MmcSubCommand scmd, int iTrack, bool bOn )
 {
 	unsigned char data[4];
-	int iMask = (1 << (iTrack < 2 ? iTrack + 5 : (iTrack - 2) % 7));
+	const int iMask = (1 << (iTrack < 2 ? iTrack + 5 : (iTrack - 2) % 7));
 
 	data[0] = scmd;
 	data[1] = (unsigned char) (iTrack < 2 ? 0 : 1 + (iTrack - 2) / 7);
@@ -495,7 +494,7 @@ void qmidictlMainForm::sendData2 (
 void qmidictlMainForm::sendPitchBend ( unsigned short iChannel, int iValue )
 {
 	unsigned char data[3];
-	unsigned short val = (unsigned short) (0x2000 + iValue);
+	const unsigned short val = (unsigned short) (0x2000 + iValue);
 
 	data[0] = 0xe0 + iChannel;
 	data[1] = (val & 0x007f);
@@ -554,7 +553,7 @@ void qmidictlMainForm::sendCommand ( int iCommand, int iTrack, int iValue )
 	if (key.isLogarithmic())
 		iValue = int(127.0f * cbrtf2(float(iValue) / 127.0f));
 
-	bool bOn = (iValue > 0);
+	const bool bOn = (iValue > 0);
 	switch (key.type()) {
 	case qmidictlMidiControl::MMC:
 		switch (command) {
@@ -683,12 +682,7 @@ void qmidictlMainForm::resetSlot (void)
 // Rewind action slot
 void qmidictlMainForm::rewindSlot ( bool bOn )
 {
-	if (m_iBusy > 0)
-		return;
-
-	m_iBusy++;
 	m_ui.forwardButton->setChecked(false);
-	m_iBusy--;
 
 	sendCommand(qmidictlMidiControl::REW, 0, int(bOn));
 }
@@ -697,9 +691,6 @@ void qmidictlMainForm::rewindSlot ( bool bOn )
 // Start/Play action slot
 void qmidictlMainForm::playSlot ( bool bOn )
 {
-	if (m_iBusy > 0)
-		return;
-
 	sendCommand(qmidictlMidiControl::PLAY, 0, int(bOn));
 }
 
@@ -707,15 +698,10 @@ void qmidictlMainForm::playSlot ( bool bOn )
 // Stop action slot
 void qmidictlMainForm::stopSlot (void)
 {
-	if (m_iBusy > 0)
-		return;
-
-	m_iBusy++;
 	m_ui.rewindButton->setChecked(false);
 	m_ui.forwardButton->setChecked(false);
 	m_ui.recordButton->setChecked(false);
 	m_ui.playButton->setChecked(false);
-	m_iBusy--;
 
 	sendCommand(qmidictlMidiControl::STOP);
 }
@@ -724,9 +710,6 @@ void qmidictlMainForm::stopSlot (void)
 // Record action slot
 void qmidictlMainForm::recordSlot ( bool bOn )
 {
-	if (m_iBusy > 0)
-		return;
-
 	sendCommand(qmidictlMidiControl::REC, 0, int(bOn));
 }
 
@@ -734,12 +717,7 @@ void qmidictlMainForm::recordSlot ( bool bOn )
 // Forward action slot
 void qmidictlMainForm::forwardSlot ( bool bOn )
 {
-	if (m_iBusy > 0)
-		return;
-
-	m_iBusy++;
 	m_ui.rewindButton->setChecked(false);
-	m_iBusy--;
 
 	sendCommand(qmidictlMidiControl::FFWD, 0, int(bOn));
 }
@@ -757,8 +735,6 @@ void qmidictlMainForm::recvData ( unsigned char *data, unsigned short len )
 	if (pMidiControl == nullptr)
 		return;
 
-	m_iBusy++;
-
 #ifdef CONFIG_DEBUG
 	fprintf(stderr, "recvData:");
 	for(int i = 0; i < len; ++i)
@@ -773,7 +749,7 @@ void qmidictlMainForm::recvData ( unsigned char *data, unsigned short len )
 	}
 
 	// Handle immediate incoming MIDI data...
-	int iTracks = (4 * m_iStripPages);
+	const int iTracks = (4 * m_iStripPages);
 	int iTrack  = -1;
 
 	qmidictlMidiControl::ControlType ctype
@@ -785,11 +761,12 @@ void qmidictlMainForm::recvData ( unsigned char *data, unsigned short len )
 	// SysEx (actually)...
 	if (data[0] == 0xf0 && data[len - 1] == 0xf7) {
 		// MMC command...
-		unsigned char mmcid = qmidictlOptions::getInstance()->iMmcDevice;
+		const unsigned char mmcid
+			= qmidictlOptions::getInstance()->iMmcDevice;
 		if (data[1] == 0x7f && data[3] == 0x06
 			&& (mmcid == 0x7f || data[2] == mmcid)) {
 			ctype = qmidictlMidiControl::MMC;
-			MmcCommand cmd = MmcCommand(data[4]);
+			const MmcCommand cmd = MmcCommand(data[4]);
 			switch (cmd) {
 			case MMC_STOP:
 			case MMC_RESET:
@@ -824,7 +801,7 @@ void qmidictlMainForm::recvData ( unsigned char *data, unsigned short len )
 				break;
 			case MMC_MASKED_WRITE:
 				if (int(data[5]) > 3) {
-					MmcSubCommand scmd = MmcSubCommand(data[6]);
+					const MmcSubCommand scmd = MmcSubCommand(data[6]);
 					iTrack = (data[7] > 0 ? (data[7] * 7) : 0) - 5;
 					iValue = int(false);
 					for (int i = 0; i < 7; ++i) {
@@ -896,7 +873,7 @@ void qmidictlMainForm::recvData ( unsigned char *data, unsigned short len )
 		= pMidiControl->find(ctype, iChannel, iParam);
 	if (iter != pMidiControl->controlMap().constEnd()) {
 		const qmidictlMidiControl::MapKey& key = iter.key();
-		qmidictlMidiControl::Command command = iter.value();
+		const qmidictlMidiControl::Command command = iter.value();
 		if (key.isChannelTrack())
 			iTrack  = int(iChannel);
 		else if (key.isParamTrack()) {
@@ -956,7 +933,7 @@ void qmidictlMainForm::recvData ( unsigned char *data, unsigned short len )
 	}
 
 	// Update corresponding strip state, when currently visible...
-	int iStrip = (4 * m_iCurrentStripPage);
+	const int iStrip = (4 * m_iCurrentStripPage);
 	if (iTrack >= iStrip && iTrack < iStrip + 4) {
 		switch (iTrack % 4) {
 		case 0: loadStripState(m_ui.strip1, iTrack); break;
@@ -965,9 +942,6 @@ void qmidictlMainForm::recvData ( unsigned char *data, unsigned short len )
 		case 3: loadStripState(m_ui.strip4, iTrack); break;
 		}
 	}
-
-	// Done.
-	m_iBusy--;
 }
 
 
